@@ -4,14 +4,14 @@ The main entry point should be through the Client. The other
 classes provide more modular functionality.
 """
 from rime_sdk.client import Client, ImageType, RIMEClient
+from rime_sdk.data_collector import DataCollector
 from rime_sdk.firewall import Firewall
 from rime_sdk.image_builder import RIMEImageBuilder
 from rime_sdk.job import ContinuousTestJob, Job
 from rime_sdk.project import Project
-from rime_sdk.protos.image_registry.image_registry_pb2 import ManagedImage
-from rime_sdk.protos.model_testing.model_testing_pb2 import CustomImage
+from rime_sdk.swagger.swagger_client.models import RimeCustomImage, RimeManagedImage
+from rime_sdk.test_batch import TestBatch
 from rime_sdk.test_run import ContinuousTestRun, TestRun
-from rime_sdk.tests import TestBatch
 
 __all__ = [
     "Client",
@@ -23,7 +23,8 @@ __all__ = [
     "TestBatch",
     "Firewall",
     "RIMEImageBuilder",
-    "CustomImage",
-    "ManagedImage",
+    "RimeCustomImage",
+    "RimeManagedImage",
     "RIMEClient",
+    "DataCollector",
 ]
