@@ -104,7 +104,10 @@ def _load_data(data_path: Path) -> List[dict]:
 
 
 def check_json_nlp_data(
-    file_path: Path, schema: Schema = None, task: str = "", input_type: str = None
+    file_path: Path,
+    schema: Schema = None,
+    task: str = "",
+    input_type: Optional[str] = None,
 ) -> None:
     """Validate that all objects in the loaded JSON data match the given Schema.
 
@@ -208,8 +211,8 @@ class NlpDataFormatChecker(DataFormatChecker):
         ref_path: Path,
         eval_path: Path,
         task: str = "",
-        preds_ref_path: Path = None,
-        preds_eval_path: Path = None,
+        preds_ref_path: Optional[Path] = None,
+        preds_eval_path: Optional[Path] = None,
         **kwargs: Any,
     ) -> None:
         """Execute NLP data checks based on provided inputs.
