@@ -1,5 +1,6 @@
 """Library defining the interfaces for monitoring jobs in the RIME backend."""
 
+import re
 import time
 from abc import ABC, abstractmethod
 from datetime import datetime
@@ -201,13 +202,19 @@ class BaseJob(ABC):
         model_testing_api = swagger_client.ModelTestingApi(self._api_client)
         if job.status == RimeJobStatus.FAILED:
             try:
-                for log_res in model_testing_api.model_testing_get_latest_logs(
+                response = model_testing_api.model_testing_get_latest_logs(
                     job_id=self._job_id
-                ):
-                    print(log_res.chunk)
+                )
+                if response.result.chunk:
+                    print(
+                        "\nLogs from failed job:\n"
+                        + self._format_logs(response.result.chunk)
+                    )
+                else:
+                    print("No logs found.")
             except ApiException as e:
                 if e.status == HTTPStatus.NOT_FOUND:
-                    print("Unable to retrieve logs for failed job")
+                    print("Unable to retrieve logs for failed job.")
                 else:
                     raise ValueError(e.reason) from None
 
@@ -223,6 +230,12 @@ class BaseJob(ABC):
 
         return job_dict
 
+    @staticmethod
+    def _format_logs(logs_string: str) -> str:
+        # Required to remove any warnings which contain endpoint information from logs.
+        logs_without_warning = re.sub(r"^WARNING(.*?)recommended!\n$", "", logs_string)
+        return logs_without_warning
+
     def _get_test_run_dict(self) -> dict:
         """Return a dictionary that is used to help pretty-print this object."""
         return {}
